@@ -12,7 +12,7 @@ cnames = dict(zip('krgybmcwd', colors + ('default',)))
 def func_for_letter(l, default='k'):
     if l == 'd':
         l = default
-    return partial(fg=cnames[l], bold=(l.lower() != l))
+    return partial(fmtstr, fg=cnames[l], bold=(l.lower() != l))
 
 def color_for_letter(l, default='k'):
     if l == 'd':
